@@ -310,7 +310,10 @@ class MainHandler(tornado.web.RequestHandler):
         pass
 
     def options(self, *args, **kwargs):
-        self._logger.info(f'Ignoring OPTIONS {self.request.uri}')
+        # self._logger.info(f'Ignoring OPTIONS {self.request.uri}')
+        self.set_header('Access-Control-Allow-Origin', '*')
+        self.set_header('Access-Control-Allow-Methods', 'DELETE,GET,HEAD,OPTIONS,POST,PUT')
+        self.set_header('Access-Control-Allow-Headers', '*')
 
     def post(self, *args, **kwargs):
         self.do(args, kwargs)
