@@ -132,7 +132,11 @@ class ApplicationService(BaseRdbmsService):
     #               'app_id_list': app_id_list })
     #         return [ row.get_value('app_id', cast.string_to_uuid) for row in cursor.fetch_all() ]
 
-    def get_application(self, app_id, check_status=False):
+    def get_application(
+            self,
+            app_id,
+            check_status=False,
+            connection=None):
         """
         Return extended information about the application specified by its
         identification.
@@ -148,6 +152,8 @@ class ApplicationService(BaseRdbmsService):
             current status of this application and raise an exception if it is
             not of enabled.
 
+        :param connection: An object `RdbmsConnection`.
+
 
         :return: An object containing the following members:
 
@@ -200,28 +206,32 @@ class ApplicationService(BaseRdbmsService):
         """
         # Retrieve the information of the application specified by its
         # identification.
-        with self.acquire_rdbms_connection() as connection:
+        with self.acquire_rdbms_connection(auto_commit=False, connection=connection) as connection:
             cursor = connection.execute(
                 """
-                SELECT app_id,
-                       app_name
-                       package_name,
-                       picture_id,
-                       stage,
-                       platform,
-                       consumer_key,
-                       consumer_secret,
-                       account_id,
-                       team_id,
-                       object_status,
-                       creation_time,
-                       update_time
-                  FROM application
-                  WHERE app_id = %(app_id)s
+                SELECT 
+                    app_id,
+                    app_name
+                    package_name,
+                    picture_id,
+                    stage,
+                    platform,
+                    consumer_key,
+                    consumer_secret,
+                    account_id,
+                    team_id,
+                    object_status,
+                    creation_time,
+                    update_time
+                  FROM
+                    application
+                  WHERE
+                    app_id = %(app_id)s
                 """,
                 {
                     'app_id': app_id
-                })
+                }
+            )
             row = cursor.fetch_one()
 
             if row is None:
@@ -236,14 +246,15 @@ class ApplicationService(BaseRdbmsService):
                 'platform': ApplicationPlatform,
                 'stage': ApplicationStage,
                 'team_id': cast.string_to_uuid,
-                'update_time': cast.string_to_timestamp})
+                'update_time': cast.string_to_timestamp
+            })
 
             # Check the current status of the application.
             if check_status:
                 if application.object_status == ObjectStatus.deleted:
-                    raise ApplicationService.DeletedObjectException(f'Application "{app_id}" deleted')
+                    raise ApplicationService.DeletedObjectException(f'Application "{app_id}" is deleted')
                 elif application.object_status == ObjectStatus.disabled:
-                    raise ApplicationService.DisabledObjectException(f'Application "{app_id}" disabled')
+                    raise ApplicationService.DisabledObjectException(f'Application "{app_id}" is disabled')
 
             return application
 
@@ -501,12 +512,12 @@ class ApplicationService(BaseRdbmsService):
         elif application.object_status == ObjectStatus.disabled:
             raise ApplicationService.DisabledObjectException('Application disabled')
 
-        # Check whether the HTTP request signature is valid, when required or
-        # requested.
-        if application.stage == ApplicationStage.live or strict:
-            if api_sig is None:
-                raise self.IncorrectSignatureException('Undefined HTTP request signature')
+        # Check whether the HTTP request signature is required.
+        if (application.stage == ApplicationStage.live or strict) and api_sig is None:
+            raise self.IncorrectSignatureException('Undefined HTTP request signature')
 
+        # Check whether the HTTP request signature is valid.
+        if api_sig:
             # Replace %xx escapes from the query string with their single-character
             # equivalent.  Client applications generally build query string without
             # escaping special characters, while the HTTP library they used will do
